@@ -17,6 +17,8 @@
 
 from __future__ import print_function
 
+import collections
+
 from keystoneauth1.identity import generic as ks_id
 from keystoneauth1 import session
 from swiftclient.client import Connection
@@ -45,3 +47,33 @@ def get_swift_client(preauthurl, preauthtoken):
                       retries=10,
                       starting_backoff=3,
                       max_backoff=120)
+
+
+def get_nested(data, name, path):
+    # Finds and returns a property from a nested dictionary by
+    # following a path of a defined set of property names and types.
+
+    def deep_find_key(key_data, data, name):
+        key, instance_type, instance_name = key_data
+        if key in data.keys():
+            if not isinstance(data[key], instance_type):
+                raise ValueError("The '{}' property of '{}' must be a {}."
+                                 "".format(key, name, instance_name))
+            return data[key]
+        for item in data.values():
+            if isinstance(item, collections.Mapping):
+                return deep_find_key(key_data, item, name)
+        return None
+
+    if not isinstance(data, collections.Mapping):
+        raise ValueError(
+            "'{}' is not a valid resource.".format(name))
+
+    current_value = data
+    while len(path) > 0:
+        key_data = path.pop(0)
+        current_value = deep_find_key(key_data, current_value, name)
+        if current_value is None:
+            break
+
+    return current_value
